==> google-music-utils-2.1.0.tar.gz: google-music-utils-2.1.0/README.md <==
# google-music-utils

[![PyPI](https://img.shields.io/pypi/v/google-music-utils.svg?label=PyPI)](https://pypi.org/project/google-music-utils/)
![](https://img.shields.io/badge/Python-3.6%2B-blue.svg)  
[![Travis](https://img.shields.io/travis/thebigmunch/google-music-utils.svg?label=Travis)](https://travis-ci.org/thebigmunch/google-music-utils)
[![Codecov](https://img.shields.io/codecov/c/github/thebigmunch/google-music-utils.svg?label=Codecov)](https://codecov.io/gh/thebigmunch/google-music-utils)  
[![Docs - Stable](https://img.shields.io/readthedocs/google-music-utils/stable.svg?label=Docs%20%28Stable%29)](https://google-music-utils.readthedocs.io/en/stable/)
[![Docs - Latest](https://img.shields.io/readthedocs/google-music-utils/latest.svg?label=Docs%20%28Latest%29)](https://google-music-utils.readthedocs.io/en/latest/)


[google-music-utils](https://github.com/thebigmunch/google-music-utils) is a
set of utility functionality for google-music and related projects.


## Installation

``pip install google-music-utils``


## Usage

For the release version, see the [stable docs](https://google-music-utils.readthedocs.io/en/stable/).  
For the development version, see the [latest docs](https://google-music-utils.readthedocs.io/en/latest/).


## Appreciation

Showing appreciation is always welcome.

#### Thank

[![Say Thanks](https://img.shields.io/badge/thank-thebigmunch-blue.svg?style=flat-square)](https://saythanks.io/to/thebigmunch)

Get your own thanks inbox at [SayThanks.io](https://saythanks.io/).

#### Contribute

[Contribute](https://github.com/thebigmunch/google-music-utils/blob/master/.github/CONTRIBUTING.md) by submitting bug reports, feature requests, or code.

#### Help Others/Stay Informed

[Discourse forum](https://forum.thebigmunch.me/)

#### Referrals/Donations

[![Coinbase](https://img.shields.io/badge/Coinbase-referral-orange.svg?style=flat-square)](https://www.coinbase.com/join/52502f01e0fdd4d3ef000253) [![Digital Ocean](https://img.shields.io/badge/Digital_Ocean-referral-orange.svg?style=flat-square)](https://m.do.co/c/3823208a0597) [![Namecheap](https://img.shields.io/badge/Namecheap-referral-orange.svg?style=flat-square)](https://www.namecheap.com/?aff=67208) [![PayPal](https://img.shields.io/badge/PayPal-donate-brightgreen.svg?style=flat-square)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=DHDVLSYW8V8N4&lc=US&item_name=thebigmunch&currency_code=USD)

**BTC:** ``1BMLCFPcX8YHE1He2t3aBrsNDGr1pKhfFa``  
**ETH:** ``0x8E3f8d8eAedeA61Bf34A998A2104954FE508D5d0``  
**LTC:** ``LgsQU1YaY4a4s7m9efjn6m35XhVEpW1xoP``

==> google-music-utils-2.2.0.tar.gz: google-music-utils-2.2.0/README.md <==
# google-music-utils

[![PyPI](https://img.shields.io/pypi/v/google-music-utils.svg?label=PyPI)](https://pypi.org/project/google-music-utils/)
![](https://img.shields.io/badge/Python-3.6%2B-blue.svg)  
[![Travis](https://img.shields.io/travis/thebigmunch/google-music-utils.svg?label=Travis)](https://travis-ci.org/thebigmunch/google-music-utils)
[![Codecov](https://img.shields.io/codecov/c/github/thebigmunch/google-music-utils.svg?label=Codecov)](https://codecov.io/gh/thebigmunch/google-music-utils)  
[![Docs - Stable](https://img.shields.io/readthedocs/google-music-utils/stable.svg?label=Docs%20%28Stable%29)](https://google-music-utils.readthedocs.io/en/stable/)
[![Docs - Latest](https://img.shields.io/readthedocs/google-music-utils/latest.svg?label=Docs%20%28Latest%29)](https://google-music-utils.readthedocs.io/en/latest/)


[google-music-utils](https://github.com/thebigmunch/google-music-utils) is a
set of utility functionality for google-music and related projects.


## Installation

``pip install -U google-music-utils``


## Usage

For the release version, see the [stable docs](https://google-music-utils.readthedocs.io/en/stable/).  
For the development version, see the [latest docs](https://google-music-utils.readthedocs.io/en/latest/).


## Appreciation

Showing appreciation is always welcome.

#### Thank

[![Say Thanks](https://img.shields.io/badge/thank-thebigmunch-blue.svg?style=flat-square)](https://saythanks.io/to/thebigmunch)

Get your own thanks inbox at [SayThanks.io](https://saythanks.io/).

#### Contribute

[Contribute](https://github.com/thebigmunch/google-music-utils/blob/master/.github/CONTRIBUTING.md) by submitting bug reports, feature requests, or code.

#### Help Others/Stay Informed

[Discourse forum](https://forum.thebigmunch.me/)

#### Referrals/Donations

[![Coinbase](https://img.shields.io/badge/Coinbase-referral-orange.svg?style=flat-square)](https://www.coinbase.com/join/52502f01e0fdd4d3ef000253) [![Digital Ocean](https://img.shields.io/badge/Digital_Ocean-referral-orange.svg?style=flat-square)](https://m.do.co/c/3823208a0597) [![Namecheap](https://img.shields.io/badge/Namecheap-referral-orange.svg?style=flat-square)](https://www.namecheap.com/?aff=67208) [![PayPal](https://img.shields.io/badge/PayPal-donate-brightgreen.svg?style=flat-square)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=DHDVLSYW8V8N4&lc=US&item_name=thebigmunch&currency_code=USD)

**BTC:** ``1BMLCFPcX8YHE1He2t3aBrsNDGr1pKhfFa``  
**ETH:** ``0x8E3f8d8eAedeA61Bf34A998A2104954FE508D5d0``  
**LTC:** ``LgsQU1YaY4a4s7m9efjn6m35XhVEpW1xoP``
